==> jc-1.4.0.tar.gz: soot/dava/toolkits/base/finders/AbruptEdgeFinder.h <==
// public class soot.dava.toolkits.base.finders.AbruptEdgeFinder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2b0898c22bc99c5d soot_dava_toolkits_base_finders_AbruptEdgeFinder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_toolkits_base_finders_AbruptEdgeFinder_H_
#define _JC_soot_dava_toolkits_base_finders_AbruptEdgeFinder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_dava_DavaBody$object;
struct _jc_soot_dava_internal_SET_SETNode$object;
struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object;
struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$object;
struct _jc_soot_util_IterableSet$object;

// Typedefs
typedef struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$sub_refs	_jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$sub_refs;
typedef struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$sub_nonrefs	_jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$sub_nonrefs;
typedef struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$refs	_jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$refs;
typedef struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$nonrefs	_jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$nonrefs;
typedef struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$object	_jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$object;

typedef const struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$vmethods	_jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$vmethods;
typedef const struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$vtable	_jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$vtable;
typedef const struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$vtype	_jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$vtype;

// Constructors
extern void _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$method$find$6aba89b6167e2073(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$object *, struct _jc_soot_dava_DavaBody$object *, struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object *, struct _jc_soot_dava_internal_SET_SETNode$object *);
extern void _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$method$find__5fBreaks$7da957732b633621(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$object *, struct _jc_soot_dava_internal_SET_SETNode$object *, struct _jc_soot_dava_internal_SET_SETNode$object *);
extern void _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$method$find__5fContinues$c244d73dcd1852b3(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$object *, struct _jc_soot_dava_internal_SET_SETNode$object *, struct _jc_soot_util_IterableSet$object *, struct _jc_soot_util_IterableSet$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$method_info$find$6aba89b6167e2073;
extern _jc_method _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$method_info$find__5fBreaks$7da957732b633621;
extern _jc_method _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$method_info$find__5fContinues$c244d73dcd1852b3;

// Static methods
extern struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$object *_jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$method$v$e6c609600b7180cd(_jc_env *);

// Virtual methods structure
struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$vmethods {
	void	(*find$6aba89b6167e2073)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$object *, struct _jc_soot_dava_DavaBody$object *, struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object *, struct _jc_soot_dava_internal_SET_SETNode$object *);
	void	(*find__5fBreaks$7da957732b633621)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$object *, struct _jc_soot_dava_internal_SET_SETNode$object *, struct _jc_soot_dava_internal_SET_SETNode$object *);
	void	(*find__5fContinues$c244d73dcd1852b3)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$object *, struct _jc_soot_dava_internal_SET_SETNode$object *, struct _jc_soot_util_IterableSet$object *, struct _jc_soot_util_IterableSet$object *);
};

// Vtable
struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$vmethods	soot_dava_toolkits_base_finders_AbruptEdgeFinder;
};

// Vtype
struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$vtype {
	_jc_type			type;
	_jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$refs {
    _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$sub_refs	soot_dava_toolkits_base_finders_AbruptEdgeFinder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$sub_nonrefs	soot_dava_toolkits_base_finders_AbruptEdgeFinder;
};

// Object instance structure
struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$object {
	_jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$vtype	*vtype;
	_jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$vtype _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_toolkits_base_finders_AbruptEdgeFinder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$class_object;

#endif	/* _JC_soot_dava_toolkits_base_finders_AbruptEdgeFinder_H_ */

==> jc-1.4.6.tar.gz: soot/dava/toolkits/base/finders/AbruptEdgeFinder.h <==
// public class soot.dava.toolkits.base.finders.AbruptEdgeFinder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2b0898c22bc99c5d soot_dava_toolkits_base_finders_AbruptEdgeFinder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_toolkits_base_finders_AbruptEdgeFinder_H_
#define _JC_soot_dava_toolkits_base_finders_AbruptEdgeFinder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_dava_DavaBody$object;
struct _jc_soot_dava_internal_SET_SETNode$object;
struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object;
struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$object;
struct _jc_soot_util_IterableSet$object;

// Typedefs
typedef struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$sub_refs	_jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$sub_refs;
typedef struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$sub_nonrefs	_jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$sub_nonrefs;
typedef struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$refs	_jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$refs;
typedef struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$nonrefs	_jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$nonrefs;
typedef struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$object	_jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$object;

typedef const struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$vmethods	_jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$vmethods;
typedef const struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$vtable	_jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$vtable;
typedef const struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$vtype	_jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$vtype;

// Constructors
extern void _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$method$find$6aba89b6167e2073(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$object *, struct _jc_soot_dava_DavaBody$object *, struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object *, struct _jc_soot_dava_internal_SET_SETNode$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$method$find__5fBreaks$7da957732b633621(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$object *, struct _jc_soot_dava_internal_SET_SETNode$object *, struct _jc_soot_dava_internal_SET_SETNode$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$method$find__5fContinues$c244d73dcd1852b3(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$object *, struct _jc_soot_dava_internal_SET_SETNode$object *, struct _jc_soot_util_IterableSet$object *, struct _jc_soot_util_IterableSet$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$method_info$find$6aba89b6167e2073;
extern _jc_method _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$method_info$find__5fBreaks$7da957732b633621;
extern _jc_method _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$method_info$find__5fContinues$c244d73dcd1852b3;

// Static methods
extern struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$object *_jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$method$v$e6c609600b7180cd(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$vmethods {
	void	(*find$6aba89b6167e2073)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$object *, struct _jc_soot_dava_DavaBody$object *, struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object *, struct _jc_soot_dava_internal_SET_SETNode$object *) _JC_JCNI_ATTR;
	void	(*find__5fBreaks$7da957732b633621)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$object *, struct _jc_soot_dava_internal_SET_SETNode$object *, struct _jc_soot_dava_internal_SET_SETNode$object *) _JC_JCNI_ATTR;
	void	(*find__5fContinues$c244d73dcd1852b3)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$object *, struct _jc_soot_dava_internal_SET_SETNode$object *, struct _jc_soot_util_IterableSet$object *, struct _jc_soot_util_IterableSet$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$vmethods	soot_dava_toolkits_base_finders_AbruptEdgeFinder;
};

// Vtype
struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$vtype {
	_jc_type			type;
	_jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$refs {
    _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$sub_refs	soot_dava_toolkits_base_finders_AbruptEdgeFinder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$sub_nonrefs	soot_dava_toolkits_base_finders_AbruptEdgeFinder;
};

// Object instance structure
struct _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$object {
	_jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$vtype	*vtype;
	_jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$vtype _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_toolkits_base_finders_AbruptEdgeFinder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_toolkits_base_finders_AbruptEdgeFinder$class_object;

#endif	/* _JC_soot_dava_toolkits_base_finders_AbruptEdgeFinder_H_ */
